@@ -83,9 +83,13 @@ pub enum MouseButton {
 /// to mutate it according to events in the interface.
 pub struct Pizarra {
     storage: Storage,
+
+    /// What is happening with the board right now?
+    board_state: BoardState,
+    selected_tool: SelectedTool,
     current_shape: Option<Box<dyn ShapeBuilder>>,
 
-    selected_tool: SelectedTool,
+    /// Some paremeters used during drawing
     selected_color: Color,
     bgcolor: Color,
     stroke: f64,
@@ -105,8 +109,6 @@ pub struct Pizarra {
     undo_state: UndoState,
     undo_queue: Vec<Action>,
 
-    /// What is happening with the board right now?
-    board_state: BoardState,
     /// Is the shift key pressed on the keyboard?
     is_shift_pressed: bool,
 
@@ -204,7 +206,7 @@ impl Pizarra {
                     self.erased.push(shape);
                 }
 
-                if self.erased.len() > 0 {
+                if !self.erased.is_empty() {
                     Action::Erase(self.erased.drain(..).collect())
                 } else {
                     Action::Empty
@@ -261,7 +263,7 @@ impl Pizarra {
             },
 
             Action::Redraw(ids) => {
-                let shapes = ids.into_iter().map(|id| self.storage.remove(id)).filter_map(|maybe_shape| maybe_shape).collect();
+                let shapes = ids.into_iter().map(|id| self.storage.remove(id)).flatten().collect();
 
                 Action::Erase(shapes)
             },
@@ -389,11 +391,11 @@ impl Pizarra {
 
     /// Notify the application that the screen size has changed
     pub fn resize(&mut self, new_size: Vec2DScreen) {
-        log::debug!("resize({})", new_size);
+        log::debug!("resize({:?})", new_size);
 
         let delta = (self.dimensions * -1.0 + new_size) * 0.5;
 
-        self.translate(delta.into());
+        self.translate(delta);
         self.dimensions = new_size;
     }
 
@@ -541,18 +543,16 @@ impl Pizarra {
     pub fn handle_key_pressed(&mut self, key: Key) {
         log::debug!("handle_key_pressed({:?})", key);
 
-        match key {
-            Key::Shift => { self.is_shift_pressed = true; }
-            _ => { }
+        if let Key::Shift = key {
+           self.is_shift_pressed = true;
         }
     }
 
     pub fn handle_key_released(&mut self, key: Key) {
         log::debug!("handle_key_released({:?})", key);
 
-        match key {
-            Key::Shift => { self.is_shift_pressed = false; }
-            _ => { }
+        if let Key::Shift = key {
+            self.is_shift_pressed = false;
         }
     }
 
